package game.command;

import java.util.List;

import game.collect.Lists;
import game.entity.Entity;
import game.entity.types.EntityLiving;
import game.world.WorldServer;

public class EntityParser extends PlayerEntityParser {
	protected final boolean livingOnly;
	
	public EntityParser(String name, boolean useSender, boolean livingOnly) {
		super(name, useSender);
		this.livingOnly = livingOnly;
	}

	public Object parse(ScriptEnvironment env, String input) {
		Entity entity = null;
		if(input.startsWith("#")) {
			int id = -1;
			try {
				id = Integer.parseInt(input.substring(1));
			}
			catch(NumberFormatException e) {
			}
			if(id != -1) {
				for(WorldServer world : env.getServer().getWorlds()) {
					entity = world.getEntityByID(id);
					if(entity != null)
						break;
				}
			}
		}
		else {
			entity = (Entity)super.parse(env, input);
		}
		if(entity == null)
			throw new ScriptException("Objekt '%s' wurde nicht gefunden", input);
		else if(this.livingOnly && !(entity instanceof EntityLiving))
			throw new ScriptException("Objekt muss lebendig sein");
		return entity;
	}
	
	public Object getDefault(ScriptEnvironment env) {
		return this.useSender && (this.livingOnly ? (env.getExecutor() instanceof EntityLiving) : (env.getExecutor() instanceof Entity)) ? env.getExecutor() : super.getDefault(env);
	}
	
	public String[] getCompletions(ScriptEnvironment env) {
		Entity target = env.getExecutor().getPointedEntity();
		List<String> comp = target == null || (this.livingOnly && !(target instanceof EntityLiving)) ? Lists.newArrayList() : Lists.newArrayList("#" + target.getId());
		comp.addAll(env.getServer().getAllUsernames());
		return comp.toArray(new String[comp.size()]);
	}

	public Class<?> getTypeClass() {
		return this.livingOnly ? EntityLiving.class : Entity.class;
	}
}
