package game.command.commands;

import java.util.List;
import game.collect.Lists;
import game.command.ScriptEnvironment;
import game.command.ScriptExecutable;
import game.command.ScriptExecutor;
import game.entity.types.EntityLiving;
import game.potion.Potion;
import game.potion.PotionEffect;

public class CommandPotion extends ScriptExecutable {
	public CommandPotion() {
		super("potion");
		
		List<Potion> potions = Lists.newArrayList();
		for(Potion potion : Potion.POTION_TYPES) {
			if(potion != null)
				potions.add(potion);
		}
		this.addLivingEntityList("entities", true);
		this.addEnum("type", Potion.class, potions);
		this.setParamsOptional();
		this.addInt("duration", 1, 1000000, 1000000);
		this.addInt("strength", 1, 256, 1);
		
		this.addFlag("particles", 'p');
		this.addFlag("ambient", 'a');
		this.addFlag("keep", 'k');
	}
	
	public Object exec(ScriptEnvironment env, ScriptExecutor exec, List<EntityLiving> entities, Potion type, int duration, int strength, boolean particles, boolean ambient, boolean keep) {
		for(EntityLiving entity : entities) {
			if(!keep && entity.hasEffect(type))
				entity.removeEffect(type.id);
			entity.addEffect(new PotionEffect(type.id, duration * 20, strength - 1, ambient, particles));
			exec.logConsole("%d * %s für %d Sekunden an %s gegeben", strength, type.getDisplay(), duration, entity.getCommandName());
		}
		if(entities.size() > 1)
			exec.logConsole("%d Effekte vergeben", entities.size());
		return null;
	}
}
